@@ -73,11 +73,20 @@ default_tune_control <- function(
 #' @param y A numeric vector or matrix of observations. Each row represents an
 #' observation at a time step.
 #' @param m An integer specifying the total number of MCMC iterations.
-#' @param init_fn A function to initialize the state-space model.
-#' @param transition_fn A function that defines the state transition of the
-#' state-space model.
-#' @param log_likelihood_fn A function that calculates the log-likelihood
-#' for the state-space model given latent states.
+#' @param init_fn A function that initializes the particle states. It should
+#' take `num_particles` as an argument for initializing the particles and return
+#' a vector or matrix of initial particle states. It can include any
+#' model-specific parameters as named arguments.
+#' @param transition_fn A function describing the state transition model. It
+#' should take `particles` as an argument and return the propagated particles.
+#' The function can optionally depend on time by including a time step argument
+#' `t`. It can include any model-specific parameters as named arguments.
+#' @param log_likelihood_fn A function that computes the log-likelihoods for the
+#' particles. It should take a `y` argument for the observations,
+#' the current particles, and return a numeric vector of log-likelihood
+#' values. The function can optionally depend on time by including a time step
+#' argument `t`. It can include any model-specific parameters as named
+#' arguments.
 #' @param log_priors A list of functions for computing the log-prior of each
 #' parameter.
 #' @param pilot_init_params A list of initial parameter values. Should be a list
@@ -100,13 +109,12 @@ default_tune_control <- function(
 #' transformation applied to each parameter before proposing. The proposal is
 #' made using a multivariate normal distribution on the transformed scale.
 #' Parameters are then mapped back to their original scale before evaluation.
-#' Currently supports \code{"log"}, \code{"invlogit"}, and \code{"identity"}.
+#' Currently supports \code{"log"}, \code{"logit"}, and \code{"identity"}.
 #' If \code{NULL}, the \code{"identity"} transformation is used for all
 #' parameters.
-#' @param tune_control A list generated by \code{\link{default_tune_control}}
-#' containing tuning parameters for the pilot chain, such as \code{pilot_m},
-#' \code{pilot_n}, \code{pilot_reps}, \code{pilot_proposal_sd},
-#' \code{pilot_algorithm}, and \code{pilot_resample_fn}.
+#' @param tune_control A list of pilot tuning controls
+#' (e.g., \code{pilot\_m}, \code{pilot\_reps}).
+#' See \code{\link{default_tune_control}}.
 #' @param verbose A logical value indicating whether to print information about
 #' pilot_run tuning. Defaults to \code{FALSE}.
 #' @param return_latent_state_est A logical value indicating whether to return
@@ -147,15 +155,15 @@ default_tune_control <- function(
 #' @export
 #'
 #' @examples
-#' init_fn <- function(particles) {
-#'   rnorm(particles, mean = 0, sd = 1)
+#' init_fn <- function(num_particles) {
+#'   rnorm(num_particles, mean = 0, sd = 1)
 #' }
 #' transition_fn <- function(particles, phi, sigma_x) {
 #'   phi * particles + sin(particles) +
 #'     rnorm(length(particles), mean = 0, sd = sigma_x)
 #' }
 #' log_likelihood_fn <- function(y, particles, sigma_y) {
-#'   dnorm(y, mean = particles, sd = sigma_y, log = TRUE)
+#'   dnorm(y, mean = cos(particles), sd = sigma_y, log = TRUE)
 #' }
 #' log_prior_phi <- function(phi) {
 #'   dnorm(phi, mean = 0, sd = 1, log = TRUE)
@@ -175,12 +183,19 @@ default_tune_control <- function(
 #' t_val <- 10
 #' x <- numeric(t_val)
 #' y <- numeric(t_val)
-#' x[1] <- rnorm(1, mean = 0, sd = 1)
-#' y[1] <- rnorm(1, mean = x[1], sd = 0.5)
+#' phi <- 0.8
+#' sigma_x <- 1
+#' sigma_y <- 0.5
+#'
+#' init_state <- rnorm(1, mean = 0, sd = 1)
+#' x[1] <- phi * init_state + sin(init_state) + rnorm(1, mean = 0, sd = sigma_x)
+#' y[1] <- x[1] + rnorm(1, mean = 0, sd = sigma_y)
 #' for (t in 2:t_val) {
-#'   x[t] <- 0.8 * x[t - 1] + sin(x[t - 1]) + rnorm(1, mean = 0, sd = 1)
-#'   y[t] <- x[t] + rnorm(1, mean = 0, sd = 0.5)
+#'   x[t] <- phi * x[t - 1] + sin(x[t - 1]) + rnorm(1, mean = 0, sd = sigma_x)
+#'   y[t] <- cos(x[t]) + rnorm(1, mean = 0, sd = sigma_y)
 #' }
+#' x <- c(init_state, x)
+#'
 #' # Should use much higher MCMC iterations in practice (m)
 #' pmmh_result <- pmmh(
 #'   y = y,
@@ -316,10 +331,10 @@ pmmh <- function(y, m, init_fn, transition_fn, log_likelihood_fn,
     }
 
     # Validate transformations and replace any invalid entries.
-    invalid <- !(param_transform %in% c("log", "invlogit", "identity"))
+    invalid <- !(param_transform %in% c("log", "logit", "identity"))
     if (any(invalid)) {
       warning(paste0(
-        "Only 'log', 'invlogit', and 'identity' transformations are supported.",
+        "Only 'log', 'logit', and 'identity' transformations are supported.",
         " Using 'identity' for invalid entries."
       ))
       param_transform[invalid] <- "identity"
@@ -387,16 +402,23 @@ pmmh <- function(y, m, init_fn, transition_fn, log_likelihood_fn,
 
     # Precompute the transformed proposal covariance:
     scale_vec <- sapply(seq_along(init_theta), function(j) {
-      if (param_transform[j] == "log") init_theta[j] else 1
+      if (param_transform[j] == "log") {
+        1 / init_theta[j] # dz/dtheta = 1 / theta
+      } else if (param_transform[j] == "logit") {
+        # dz/dtheta = 1 / (theta * (1 - theta))
+        1 / (init_theta[j] * (1 - init_theta[j]))
+      } else {
+        1
+      }
     })
-    proposal_cov_trans <- diag(1 / scale_vec) %*% proposal_cov %*%
-      diag(1 / scale_vec)
+    # Cov(z)=J Cov(theta) J^T, where J=diag(dz/dtheta)
+    proposal_cov_trans <- diag(scale_vec) %*% proposal_cov %*% diag(scale_vec)
 
     # ---------------------------
     # Step 2: Run the PMMH chain using the tuned settings
     # ---------------------------
 
-    message("Running particle MCMC chain with tuned settings...")
+    message("Running Particle MCMC chain with tuned settings...")
 
     current_theta <- init_theta
     theta_chain <- matrix(NA, nrow = m, ncol = num_params)
@@ -411,7 +433,7 @@ pmmh <- function(y, m, init_fn, transition_fn, log_likelihood_fn,
         init_fn = init_fn,
         transition_fn = transition_fn,
         log_likelihood_fn = log_likelihood_fn,
-        obs__times = obs_times,
+        obs_times = obs_times,
         algorithm = algorithm,
         resample_fn = resample_fn
       ),
@@ -453,7 +475,7 @@ pmmh <- function(y, m, init_fn, transition_fn, log_likelihood_fn,
           init_fn = init_fn,
           transition_fn = transition_fn,
           log_likelihood_fn = log_likelihood_fn,
-          obs__times = obs_times,
+          obs_times = obs_times,
           algorithm = algorithm,
           resample_fn = resample_fn
         ),
@@ -482,6 +504,11 @@ pmmh <- function(y, m, init_fn, transition_fn, log_likelihood_fn,
                              log_jacobian_current)
       log_accept_ratio <- log_accept_num - log_accept_denom
 
+      # If it’s NA/NaN, force it to -Inf.
+      if (is.na(log_accept_ratio)) {
+        log_accept_ratio <- -Inf
+      }
+
       if (log(runif(1)) < log_accept_ratio) {
         current_theta <- proposed_theta
         current_loglike <- proposed_loglike
